﻿#include "sysenumlistthread.h"
#include <tbaseutil/tdataresponse.h>
#include <tbaseutil/tdataparse.h>
#include <tbaseutil/thttputil.h>
#include <tbaseutil/tjsonapi.h>
#include <tdatabaseutil/tsqlconnectionpoolv2.h>
#include <tdatabaseutil/tsqlqueryv2.h>
#include <tdatabaseutil/tsqlselectorv2.h>
#include <topcore/topcore.h>

SysEnumListThread::SysEnumListThread(QObject *iParent)
    : TopClassThreadAbs(iParent)
{

}

SysEnumListThread::~SysEnumListThread()
{

}

void SysEnumListThread::run()
{
    if (invokeName() == "LOAD_DATA") {
        loadData();
    } else if (invokeName() == "SAVE_DATA") {
        saveData();
    }
}

void SysEnumListThread::loadData()
{
    QString enumNameStr = invokeParameter().toString();
    TDataResponse dataRes;
    QVariantMap bodyMap;
    bodyMap.insert("enum", QStringList() << enumNameStr);
    bodyMap.insert("product_category", APP->productCategory());

    TJsonApiResponse response = APP->httpUtil().httpRequest("/system/getSysEnumJsonConfV2", bodyMap).httpPost().toJsonApiResponse();
    if (response.hasError()) {
        dataRes.setErrText(response.firstError().title() + "\n" + response.firstError().detail());
    } else {
        dataRes.setData(TDataParse::jsonStr2Variant(response.data().toMap().value(enumNameStr).toMap().value("conf").toString()));
    }
    setInvokeResult(dataRes.toVariantMap());
}

void SysEnumListThread::saveData()
{
    TDataResponse dataRes;
    QVariantMap dataMap = invokeParameter().toMap();
    TSqlQueryV2 sqlQuery(T_SQLCNT_POOL->getSqlDatabase());
    sqlQuery.begin();
    try {
        TSqlInserterV2 sqlInserter;
        sqlInserter.setTable("sys_setting_enum");
        sqlInserter.setData(dataMap);
        sqlInserter.setField(QStringList() << "enum_name" << "conf_admin" << "md5");
        sqlInserter.setUniqueField(QStringList()<<"enum_name"<<"product_category");
        sqlInserter.setAutoIncrementField("enum_name");

        QVariant enumClassName = sqlQuery.replaceRow(sqlInserter);
        if (sqlQuery.lastError().isValid()) {
            throw sqlQuery.lastError();
        }

        sqlQuery.commit();
        dataRes.setData(enumClassName);
        setInvokeResult(dataRes.toVariantMap());
        return;
    } catch (const TError &err) {
        dataRes.setError(err);
    } catch (...) {
        dataRes.setErrText(ttr("Unknow Error!"));
    }
    sqlQuery.rollback();
    setInvokeResult(dataRes.toVariantMap());
}
